import React, { useState, useCallback, useEffect, } from 'react'; import ReactDOM from 'react-dom'; import { csv, scaleLinear, scaleOrdinal, max, format, extent, } from 'd3'; import { useData } from './useData'; import { confusionMatrix } from './confusionMatrix'; import { ColorLegend } from './ColorLegend'; import { PositionGroup } from './PositionGroup'; import { DescriptionGroup } from './DescriptionGroup'; import { ConfusionGroup } from './ConfusionGroup';  const width = 1000; const height = 600; const margin = { top: 30, right: 130,
  bottom: 100,
  left: 70,
};
const xAxisLabelOffset = 50;
const yAxisLabelOffset = 45;
const fadeOpacity = 0.2;

const App = () => {
  // TSNE data import
  const data = useData();
  const [hoveredValue, setHoveredValue] = useState(null);
  console.log(hoveredValue);
  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;
  // Confusion Matrix import
  const cm = confusionMatrix();
  const number_of_classes = 5;
  const matrix_size = 180;
  var labels = [
    'Data Analyst',
    'Data Science Manager',
    'Data Scientist',
    'Machine Learning Engineer',
    'Others',
  ];
  const rowSelector = (cm) => cm.row;
  const colSelector = (d) => d.col;
  const valueSelector = (d) => d.val;
  const row_mat_scale = d3
    .scaleBand()
    .domain(d3.range(number_of_classes))
    .range([0, matrix_size]);
  const col_mat_scale = d3
    .scaleBand()
    .domain(d3.range(number_of_classes))
    .range([0, matrix_size]);
  const cell_width = matrix_size / number_of_classes;
  const x_loc = 325;
  const y_loc = 300;
  // end of confusion matrix constants

  // begin position constants
  if (!data) {
    return <pre>Loading...</pre>;
  }

  // Everything we need to plot text at the centroid of each class
  const centroids = data
    ? data.filter((d) =>
        d.position_raw.endsWith('Centroid')
      )
    : [];
  // end of centroid constant definitions

  const xValue = (d) => d.position_tsne_1;
  const yValue = (d) => d.position_tsne_2;
  const colorValue = (d) => d.position;
  const colorLegendLabel = 'Position';

  const filteredData = data.filter(
    (d) => hoveredValue === colorValue(d)
  );

  const circleRadius = 1.5;

  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([innerWidth / 2, innerWidth]);

  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([0, (2 * innerHeight) / 3]);

  // Description constants
  const xDescrip = (d) => d.description_tsne_1;
  const yDescrip = (d) => d.description_tsne_2;
  const xDScale = scaleLinear()
    .domain(extent(data, xDescrip))
    .range([0, innerWidth / 2]);
  const yDScale = scaleLinear()
    .domain(extent(data, yDescrip))
    .range([0, (2 * innerHeight) / 3]);

  var colorScale2 = scaleLinear()
    .range(['white', '#4B87C5'])
    .domain([0, 1]);
  // end description constants

  const colorScale = scaleOrdinal()
    .domain(data.map(colorValue))
    .range([
      '#e41a1c',
      '#377eb8',
      '#4daf4a',
      '#984ea3',
      '#ff7f00',
    ]);

  // we want to display the raw position string when moused over
  const posValue = (d) => d.position_raw;
  const desValue = (d) => d.description;

  return (
    <svg width={width} height={height}>
      <g>
        <g transform={`translate(${innerWidth + 15}, 60)`}>
          <text
            x={70}
            y={-25}
            className="axis-label"
            textAnchor="middle"
          >
            {colorLegendLabel + ' Class'}
          </text>
          <ColorLegend
            tickSpacing={30}
            tickSize={10}
            tickTextOffset={12}
            tickSize={10}
            colorScale={colorScale}
            onHover={setHoveredValue}
            hoveredValue={hoveredValue}
            fadeOpacity={fadeOpacity}
          />
        </g>
        <PositionGroup
          hoveredValue={hoveredValue}
          data={data}
          xScale={xScale}
          xValue={xValue}
          yScale={yScale}
          yValue={yValue}
          posValue={posValue}
          colorScale={colorScale}
          colorValue={colorValue}
          circleRadius={circleRadius}
          centroids={centroids}
          filteredData={filteredData}
          fadeOpacity={fadeOpacity}
        />
      </g>
      <g>
        <DescriptionGroup
          hoveredValue={hoveredValue}
          data={data}
          xScale={xDScale}
          xValue={xDescrip}
          yScale={xDScale}
          yValue={yDescrip}
          posValue={desValue}
          colorScale={colorScale}
          colorValue={colorValue}
          circleRadius={circleRadius}
          centroids={centroids}
          filteredData={filteredData}
          fadeOpacity={fadeOpacity}
        />
      </g>
      <g>
        <ConfusionGroup
          data={cm}
          height={300}
          xScale={row_mat_scale}
          xSelector={rowSelector}
          yScale={col_mat_scale}
          ySelector={colSelector}
          matrix_size={matrix_size}
          num_classes={number_of_classes}
          cell_width={cell_width}
          x_loc={x_loc}
          y_loc={y_loc}
          color_scale={colorScale2}
          labels={labels}
          hoveredValue={hoveredValue}
          fadeOpacity={fadeOpacity}
        />
      </g>
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
